/// <reference types="node" />
import { Server } from "http";
import { Server as SecureServer } from "https";
import { Optional } from "typescript-optional";
import { Config as SshConfig } from "node-ssh";
import { Express } from "express";
import { IPluginLedgerConnector, IWebServiceEndpoint, IPluginWebService, ICactusPluginOptions, ConsensusAlgorithmFamily } from "@hyperledger/cactus-core-api";
import { LogLevelDesc } from "@hyperledger/cactus-common";
import { PrometheusExporter } from "./prometheus-exporter/prometheus-exporter";
export interface IPluginLedgerConnectorCordaOptions extends ICactusPluginOptions {
    logLevel?: LogLevelDesc;
    sshConfigAdminShell: SshConfig;
    corDappsDir: string;
    prometheusExporter?: PrometheusExporter;
    cordaStartCmd?: string;
    cordaStopCmd?: string;
}
export declare class PluginLedgerConnectorCorda implements IPluginLedgerConnector<any, any, any, any>, IPluginWebService {
    readonly options: IPluginLedgerConnectorCordaOptions;
    static readonly CLASS_NAME = "DeployContractJarsEndpoint";
    private readonly instanceId;
    private readonly log;
    prometheusExporter: PrometheusExporter;
    private endpoints;
    get className(): string;
    private httpServer;
    constructor(options: IPluginLedgerConnectorCordaOptions);
    getOpenApiSpec(): unknown;
    getPrometheusExporter(): PrometheusExporter;
    getPrometheusExporterMetrics(): Promise<string>;
    getConsensusAlgorithmFamily(): Promise<ConsensusAlgorithmFamily>;
    hasTransactionFinality(): Promise<boolean>;
    getInstanceId(): string;
    getPackageName(): string;
    onPluginInit(): Promise<unknown>;
    deployContract(): Promise<any>;
    transact(): Promise<any>;
    registerWebServices(app: Express): Promise<IWebServiceEndpoint[]>;
    getOrCreateWebServices(): Promise<IWebServiceEndpoint[]>;
    getHttpServer(): Optional<Server | SecureServer>;
    shutdown(): Promise<void>;
    getFlowList(): Promise<string[]>;
}
